@@ -1,6 +1,7 @@
 """
 Data Class Representing a Dune Query
 """
+import urllib.parse
 from dataclasses import dataclass
 from typing import Optional
 
@@ -15,10 +16,16 @@ class Query:
     query_id: int
     params: Optional[list[QueryParameter]] = None
 
-    def url(self) -> str:
+    def base_url(self) -> str:
         """Returns a link to query results excluding fixed parameters"""
         return f"https://dune.com/queries/{self.query_id}"
 
     def parameters(self) -> list[QueryParameter]:
         """Non-null version of self.params"""
         return self.params or []
+
+    def url(self) -> str:
+        """Returns a parameterized link to the query"""
+        # Include variable parameters in the URL so they are set
+        query = "&".join([f"{p.key}={p.value}" for p in self.parameters()])
+        return "?".join([self.base_url(), urllib.parse.quote_plus(query, safe="=&?")])
